@@ -38,3 +38,9 @@ $r->add_timeout(500, \&tick);
 
 print "Entering main loop\n";
 $r->run;
+
+# Call with a 15 second timeout, should still work
+print "Reply ", join(',', @{$object->HelloWorld(dbus_call_timeout, 15000, "Eeek")}), "\n";
+
+# Call with a 5 second timeout should fail
+print "Reply ", join(',', @{$object->HelloWorld(dbus_call_timeout, 5000, "Eeek")}), "\n";
